PR Title format: 

    Pull request title with short description

**Please** add a meaningful description for your change here

----

**Please** following this checklist to help us incorporate your contribution quickly and easily:

 - [ ] Make sure there is a ticket in project tab.
 - [ ] Give the same name to the pull request as the name of ticket 
 - [ ] Provide unit tests for your changes, especially if you are changing the behavior of existing code or adding
       significant new parts of code.
 - [ ] Write a pull request description that is detailed enough to understand what the pull request does, how, and why.
 - [ ] Test your code throughly before PR.
 
If your pull request is about ~20 lines of code add license information in your code in form of comment. i.e. # License: MIT, Author:  Your name.

To make clear that you license your contribution under the MIT you have to acknowledge this by using the following check-box.

 - [ ] I hereby declare this contribution to be licenced under the [MIT license](https://opensource.org/licenses/MIT)
